@@ -24,7 +24,10 @@ import os
 import sys
 import re
 import types
-import pyRXP
+try:
+    import pyRXP
+except ImportError:
+    import pyRXPU as pyRXP
 import exceptions
 import socket
 import cPickle
@@ -62,14 +65,14 @@ try:
     config_file = os.path.join(ldbdserver_ini, "ldbdserver.ini")
     myConfigParser.read(config_file)
 except Exception, e:
-    print >> sys.stderr, "Error: unable to read configuration file : %s" % config_file
+    sys.stder.write("Error: unable to read configuration file : %s\n" % config_file)
     sys.exit(1)
 
 for k in configuration.keys():
     try:
         value = myConfigParser.get('ldbdd',k)
     except ConfigParser.NoOptionError, e:
-        print >> sys.stderr, "Error: missing configuration option %s: %s" % (k, e)
+        sys.stderr.write("Error: missing configuration option %s: %s\n" % (k, e))
         sys.exit(1)
     try:
         configuration[k] = eval(value)
@@ -581,7 +584,7 @@ class Server(object):
             rmv_idx.append(row_idx)
           else:
             # multiple entries for this process, needs human assistance
-            raise ServerHandlerException, "multiple entries for dmt process"
+            raise ServerHandlerException("multiple entries for dmt process")
 
       # delete the duplicate processs rows and clear the table if necessary
       newstream = []
