@@ -37,6 +37,10 @@ import sys
 import urlparse
 import warnings
 
+try:  # python < 3
+    long
+except NameError:  # python >= 3
+    long = int
 
 from glue import git_version
 from glue import segments
@@ -93,7 +97,7 @@ class LIGOTimeGPS(object):
 		LIGOTimeGPS(100, 500000000)
 		>>> LIGOTimeGPS(100, 500000000)
 		LIGOTimeGPS(100, 500000000)
-		>>> LIGOTimeGPS(0, 100500000000L)
+		>>> LIGOTimeGPS(0, 100500000000)
 		LIGOTimeGPS(100, 500000000)
 		>>> LIGOTimeGPS(100.2, 300000000)
 		LIGOTimeGPS(100, 500000000)
@@ -108,17 +112,17 @@ class LIGOTimeGPS(object):
 		>>> LIGOTimeGPS("-1.2")
 		LIGOTimeGPS(-2, 800000000)
 		"""
-		if type(nanoseconds) not in (float, int, long):
+		if not isinstance(nanoseconds, (float, int, long)):
 			try:
 				nanoseconds = float(nanoseconds)
 			except:
 				raise TypeError(nanoseconds)
-		if type(seconds) is float:
+		if isinstance(seconds, float):
 			ns, seconds = math.modf(seconds)
 			seconds = int(seconds)
 			nanoseconds += ns * 1e9
-		elif type(seconds) not in (int, long):
-			if type(seconds) in (str, unicode):
+		elif not isinstance(seconds, (int, long)):
+			if isinstance(seconds, (str, unicode)):
 				sign = -1 if seconds.lstrip().startswith("-") else +1
 				try:
 					if "." in seconds:
@@ -130,15 +134,20 @@ class LIGOTimeGPS(object):
 				except:
 					raise TypeError("invalid literal for LIGOTimeGPS(): %s" % seconds)
 				nanoseconds += ns
+			elif hasattr(seconds, "gpsSeconds") and hasattr(seconds, "gpsNanoSeconds"):
+				# handle LIGOTimeGPS(x) where x is an
+				# object with gpsSeconds and gpsNanoSeconds
+				# fields.
+				nanoseconds += seconds.gpsNanoSeconds
+				seconds = seconds.gpsSeconds
+			elif hasattr(seconds, "seconds") and hasattr(seconds, "nanoseconds"):
+				# handle LIGOTimeGPS(x) where x is an
+				# object with seconds and nanoseconds
+				# fields.
+				nanoseconds += seconds.nanoseconds
+				seconds = seconds.seconds
 			else:
-				try:
-					# handle LIGOTimeGPS(x) where x is an
-					# object with seconds and nanoseconds
-					# fields.
-					nanoseconds += seconds.nanoseconds
-					seconds = seconds.seconds
-				except:
-					raise TypeError(seconds)
+				raise TypeError(seconds)
 		self.__seconds = seconds + int(nanoseconds // 1000000000)
 		self.__nanoseconds = int(nanoseconds % 1000000000)
 
@@ -202,9 +211,9 @@ class LIGOTimeGPS(object):
 		Example:
 
 		>>> LIGOTimeGPS(100.5).ns()
-		100500000000L
+		100500000000
 		"""
-		return self.__seconds * 1000000000L + self.__nanoseconds
+		return self.__seconds * 1000000000 + self.__nanoseconds
 
 	# comparison
 
@@ -226,7 +235,7 @@ class LIGOTimeGPS(object):
 		>>> LIGOTimeGPS(100.5) < "200"
 		True
 		"""
-		if not type(other) == LIGOTimeGPS:
+		if not isinstance(other, LIGOTimeGPS):
 			try:
 				other = LIGOTimeGPS(other)
 			except TypeError:
@@ -261,7 +270,7 @@ class LIGOTimeGPS(object):
 		>>> LIGOTimeGPS(100.5) + "3"
 		LIGOTimeGPS(103, 500000000)
 		"""
-		if not type(other) == LIGOTimeGPS:
+		if not isinstance(other, LIGOTimeGPS):
 			other = LIGOTimeGPS(other)
 		return LIGOTimeGPS(self.__seconds + other.seconds, self.__nanoseconds + other.nanoseconds)
 
@@ -283,7 +292,7 @@ class LIGOTimeGPS(object):
 		>>> LIGOTimeGPS(100.5) - "3"
 		LIGOTimeGPS(97, 500000000)
 		"""
-		if not type(other) == LIGOTimeGPS:
+		if not isinstance(other, LIGOTimeGPS):
 			other = LIGOTimeGPS(other)
 		return LIGOTimeGPS(self.__seconds - other.seconds, self.__nanoseconds - other.nanoseconds)
 
@@ -291,7 +300,7 @@ class LIGOTimeGPS(object):
 		"""
 		Subtract a LIGOTimeGPS from a value.
 		"""
-		if not type(other) == LIGOTimeGPS:
+		if not isinstance(other, LIGOTimeGPS):
 			other = LIGOTimeGPS(other)
 		return LIGOTimeGPS(other.seconds - self.__seconds, other.nanoseconds - self.__nanoseconds)
 
@@ -547,7 +556,7 @@ class CacheEntry(object):
 		Compare two CacheEntry objects by observatory, then
 		description, then segment, then URL.
 		"""
-		if type(other) != CacheEntry:
+		if not isinstance(other, CacheEntry):
 			raise TypeError("can only compare CacheEntry to CacheEntry")
 		return cmp((self.observatory, self.description, self.segment, self.url), (other.observatory, other.description, other.segment, other.url))
 
@@ -749,7 +758,7 @@ class Cache(list):
 		write a cache object to the fileobj as a lal cache file
 		"""
 		for entry in self:
-			print >>fileobj, str(entry)
+			fileobj.write('%s\n' % str(entry))
 		fileobj.close()
 
 	def topfnfile(self, fileobj):
@@ -757,7 +766,7 @@ class Cache(list):
 		write a cache object to filename as a plain text pfn file
 		"""
 		for entry in self:
-			print >>fileobj, entry.path
+			fileobj.write('%s\n' % entry.path)
 		fileobj.close()
 
 	def to_segmentlistdict(self):
@@ -850,7 +859,7 @@ class Cache(list):
 			msg = "%d of %d files in the cache were not found "\
 			    "on disk" % (len(c_missed), len(self))
 			if on_missing == "warn":
-				print >>sys.stderr, "warning: " + msg
+				sys.stderr.write("warning: %s\n" % msg)
 			elif on_missing == "error":
 				raise ValueError(msg)
 			elif on_missing == "ignore":
