@@ -56,7 +56,8 @@ typedef struct {
 	PyObject *formats;
 	/* the source of row objects to be turned to unicode strings */
 	PyObject *iter;
-	/* number of rows converted so far */
+	/* number of rows converted so far.  not used here, but helpful for
+	 * constructing error messages in the calling code */
 	Py_ssize_t rows_converted;
 	/* tuple of unicode tokens from most recently converted row */
 	PyObject *tokens;
@@ -164,10 +165,15 @@ static PyObject *next(PyObject *self)
 {
 	ligolw_RowDumper *rowdumper = (ligolw_RowDumper *) self;
 	const Py_ssize_t n = PyTuple_GET_SIZE(rowdumper->attributes);
+	PyObject *tokens;
 	PyObject *row;
 	PyObject *result;
 	Py_ssize_t i;
 
+	/*
+	 * retrieve the next row object
+	 */
+
 	if(!PyIter_Check(rowdumper->iter)) {
 		PyErr_SetObject(PyExc_TypeError, rowdumper->iter);
 		return NULL;
@@ -183,23 +189,32 @@ static PyObject *next(PyObject *self)
 		return NULL;
 	}
 
+	/*
+	 * wipe out the tuple of tokens from the previous row, and start a
+	 * new tuple
+	 */
+
 	Py_DECREF(rowdumper->tokens);
-	rowdumper->tokens = PyTuple_New(n);
-	if(!rowdumper->tokens) {
-		rowdumper->tokens = Py_None;
-		Py_INCREF(rowdumper->tokens);
+	rowdumper->tokens = Py_None;
+	Py_INCREF(rowdumper->tokens);
+
+	tokens = PyTuple_New(n);
+	if(!tokens) {
 		Py_DECREF(row);
 		return NULL;
 	}
 
+	/*
+	 * retrieve attributes from the row object one-by-one, convert to
+	 * strings, and insert into new token tuple
+	 */
+
 	for(i = 0; i < n; i++) {
 		PyObject *val = PyObject_GetAttr(row, PyTuple_GET_ITEM(rowdumper->attributes, i));
 		PyObject *token;
 
 		if(!val) {
-			Py_DECREF(rowdumper->tokens);
-			rowdumper->tokens = Py_None;
-			Py_INCREF(rowdumper->tokens);
+			Py_DECREF(tokens);
 			Py_DECREF(row);
 			return NULL;
 		}
@@ -211,18 +226,27 @@ static PyObject *next(PyObject *self)
 		Py_DECREF(val);
 
 		if(!token) {
-			Py_DECREF(rowdumper->tokens);
-			rowdumper->tokens = Py_None;
-			Py_INCREF(rowdumper->tokens);
+			Py_DECREF(tokens);
 			Py_DECREF(row);
 			return NULL;
 		}
 
-		PyTuple_SET_ITEM(rowdumper->tokens, i, token);
+		PyTuple_SET_ITEM(tokens, i, token);
 	}
-
 	Py_DECREF(row);
 
+	/*
+	 * that worked, so expose the new token tuple
+	 */
+
+	Py_DECREF(rowdumper->tokens);
+	rowdumper->tokens = tokens;
+
+	/*
+	 * return tokens concatenated into a single string using the
+	 * delimiter
+	 */
+
 	result = PyUnicode_Join(rowdumper->delimiter, rowdumper->tokens);
 
 	rowdumper->rows_converted += result != NULL;
