@@ -188,12 +188,22 @@ static void parse_error(PyObject *exception, const Py_UNICODE *buffer, const ptr
 {
 	PyObject *buffer_str;
 	PyObject *pos_str;
-	
+
+	/* FIXME: remove when we require 3 */
+#if PY_MAJOR_VERSION < 3
 	buffer_str = PyUnicode_Encode(buffer, buffer_length, NULL, NULL);
 	pos_str = PyUnicode_Encode(pos, 1, NULL, NULL);
+#else
+	buffer_str = PyUnicode_FromUnicode(buffer, buffer_length);
+	pos_str = PyUnicode_FromUnicode(pos, 1);
+#endif
 
 	if(buffer_str && pos_str)
+#if PY_MAJOR_VERSION < 3
 		PyErr_Format(exception, "parse error in '%s' near '%s' at position %td: %s", PyString_AS_STRING(buffer_str), PyString_AS_STRING(pos_str), pos - buffer + 1, msg);
+#else
+		PyErr_Format(exception, "parse error in '%U' near '%U' at position %td: %s", buffer_str, pos_str, pos - buffer + 1, msg);
+#endif
 	else
 		PyErr_Format(exception, "parse error (details not available): %s", msg);
 
@@ -444,11 +454,14 @@ static PyObject *append(PyObject *self, PyObject *data)
 
 	if(PyUnicode_Check(data)) {
 		fail = add_to_data((ligolw_Tokenizer *) self, data);
+	/* FIXME:  remove when we require >= 3 */
+#if PY_MAJOR_VERSION < 3
 	} else if(PyString_Check(data)) {
 		if(!(data = PyUnicode_FromObject(data)))
 			return NULL;
 		fail = add_to_data((ligolw_Tokenizer *) self, data);
 		Py_DECREF(data);
+#endif
 	} else {
 		PyErr_SetObject(PyExc_TypeError, data);
 		return NULL;
@@ -580,8 +593,11 @@ static PyObject *next(PyObject *self)
 		}
 	} else if(type == (PyObject *) &PyUnicode_Type) {
 		token = PyUnicode_FromUnicode(start, end - start);
+	/* FIXME:  remove when we require >= 3 */
+#if PY_MAJOR_VERSION < 3
 	} else if(type == (PyObject *) &PyString_Type) {
 		token = PyUnicode_Encode(start, end - start, NULL, NULL);
+#endif
 	} else if(type == (PyObject *) &PyInt_Type) {
 		token = PyInt_FromUnicode(start, end - start, 0);
 	} else if(type == (PyObject *) &PyLong_Type) {
@@ -663,7 +679,7 @@ static PyObject *attribute_get_data(PyObject *obj, void *data)
 {
 	ligolw_Tokenizer *tokenizer = (ligolw_Tokenizer *) obj;
 
-	return PyUnicode_FromUnicode(tokenizer->data, tokenizer->length - tokenizer->data);
+	return PyUnicode_FromUnicode(tokenizer->pos, tokenizer->length - tokenizer->pos);
 }
 
 
@@ -698,10 +714,15 @@ PyTypeObject ligolw_Tokenizer_Type = {
 "Tokenizer is able to directly extract tokens as various Python types.  The\n" \
 "set_types() method is passed a sequence of the types to which tokens are to be\n" \
 "converted.  The types will be used in order, cyclically.  For example, passing\n" \
-"[int] to set_types() causes all tokens to be converted to ints, while\n" \
+"[int] to set_types() causes all tokens to be converted to integers, while\n" \
 "[str, int] causes the first token to be returned as a string, the second as an\n" \
-"int, then the third as a string again, and so on.  The default is to extract\n" \
-"all tokens as strings.\n" \
+"integer, then the third as a string again, and so on.  The default is to\n" \
+"extract all tokens as strings.  If a token type is set to None then the\n" \
+"corresponding tokens are skipped.  For example, invoking set_types() with\n" \
+"[int, None] causes the first token to be converted to an integer, the second\n" \
+"to be skipped the third to be converted to an integer, and so on.  This can\n" \
+"be used to improve parsing performance when only a subset of the input stream\n" \
+"is required.\n" \
 "\n" \
 "Example:\n" \
 "\n" \
