@@ -30,13 +30,12 @@ objects.
 """
 
 
-import itertools
 import re
 
 
 from glue import git_version
-from glue import iterutils
-from glue import lal
+from glue.lal import CacheEntry
+from lal import LIGOTimeGPS
 from glue import segments
 
 
@@ -101,14 +100,14 @@ def fromlalcache(cachefile, coltype = int):
 
 	Example:
 
-	>>> from glue.lal import LIGOTimeGPS
+	>>> from lal import LIGOTimeGPS
 	>>> cache_seglists = fromlalcache(open(filename), coltype = LIGOTimeGPS).coalesce()
 
 	See also:
 
 	glue.lal.CacheEntry
 	"""
-	return segments.segmentlist(lal.CacheEntry(l, coltype = coltype).segment for l in cachefile)
+	return segments.segmentlist(CacheEntry(l, coltype = coltype).segment for l in cachefile)
 
 
 #
@@ -184,9 +183,9 @@ def tosegwizard(file, seglist, header = True, coltype = int):
 	to str() before output.
 	"""
 	if header:
-		print >>file, "# seg\tstart    \tstop     \tduration"
+		file.write("# seg\tstart    \tstop     \tduration\n")
 	for n, seg in enumerate(seglist):
-		print >>file, "%d\t%s\t%s\t%s" % (n, str(coltype(seg[0])), str(coltype(seg[1])), str(coltype(abs(seg))))
+		file.write("%d\t%s\t%s\t%s\n" % (n, str(coltype(seg[0])), str(coltype(seg[1])), str(coltype(abs(seg)))))
 
 
 #
@@ -194,7 +193,7 @@ def tosegwizard(file, seglist, header = True, coltype = int):
 #
 
 
-def fromtama(file, coltype = lal.LIGOTimeGPS):
+def fromtama(file, coltype = LIGOTimeGPS):
 	"""
 	Read a segmentlist from the file object file containing TAMA
 	locked-segments data.  Parsing stops on the first line that cannot
